@@ -1,6 +1,6 @@
 ;;; vertico-mouse.el --- Mouse support for Vertico -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
@@ -38,8 +38,8 @@
 
 (defun vertico-mouse--index (event)
   "Return candidate index at EVENT."
-  (when-let ((object (posn-object (event-end event)))
-             ((consp object)))
+  (when-let* ((object (posn-object (event-end event)))
+              ((consp object)))
     (get-text-property (cdr object) 'vertico-mouse--index (car object))))
 
 (defun vertico-mouse--click (key)
@@ -48,8 +48,8 @@
     (interactive "e")
     ;; Mouse clicks can even happen if another window is selected.
     (with-selected-window (active-minibuffer-window)
-      (when-let ((vertico--index (vertico-mouse--index event))
-                 (cmd (keymap-local-lookup key)))
+      (when-let* ((vertico--index (vertico-mouse--index event))
+                  (cmd (keymap-local-lookup key)))
         (funcall cmd)))))
 
 (defvar-keymap vertico-mouse-map
